# CHANGELOG

## v0.0.0 (2024-09-01)

### Chore

* chore: run pip install uv as part of build_command for PSR ([`9df858c`](https://github.com/takuma7/aioh/commit/9df858c7b014363185062d1942f7bf507690e76c))

* chore: set the correct value to python semantic release version_toml ([`0b92877`](https://github.com/takuma7/aioh/commit/0b928777c2ec4743e4c71f34a5e5616279acc9e2))

* chore: checkout before setting up python in ci-cd.yml ([`ede57ec`](https://github.com/takuma7/aioh/commit/ede57ec10b21082d4fec94bfa8f3730c31d7316d))

* chore: initial set up ([`c9c7df2`](https://github.com/takuma7/aioh/commit/c9c7df282d6cb32bfbd0ba41980444c8982daead))

### Unknown

* Initial commit ([`74fb8a5`](https://github.com/takuma7/aioh/commit/74fb8a5bc2fef859efbf07139aee84efa6786ba2))
